@@ -14,7 +14,7 @@ class Price(object):
     def __init__(self, net, gross=None, currency=None, previous=None,
                  modifier=None, operation=None):
         if isinstance(net, float) or isinstance(gross, float):
-            warnings.warn(
+            warnings.warn(  # pragma: no cover
                 RuntimeWarning(
                     'You should never use floats when dealing with prices!'),
                 stacklevel=2)
@@ -40,7 +40,7 @@ class Price(object):
                 raise ValueError('Cannot compare prices in %r and %r' %
                                  (self.currency, other.currency))
             return self.gross < other.gross
-        return NotImplemented
+        return NotImplemented  # pragma: no cover
 
     def __le__(self, other):
         return self < other or self == other
@@ -85,7 +85,7 @@ class Price(object):
             return Price(net=price_net, gross=price_gross,
                          currency=self.currency, previous=self, modifier=other,
                          operation=operator.__sub__)
-        return NotImplemented
+        return NotImplemented  # pragma: no cover
 
     @property
     def tax(self):
@@ -122,12 +122,12 @@ class PriceRange(object):
         self.min_price = min_price
         if max_price is None:
             max_price = min_price
-        if min_price > max_price:
-            raise ValueError('Cannot create a pricerange from %r to %r' %
-                             (min_price, max_price))
         if min_price.currency != max_price.currency:
             raise ValueError('Cannot create a pricerange as %r and %r use'
                              ' different currencies' % (min_price, max_price))
+        if min_price > max_price:
+            raise ValueError('Cannot create a pricerange from %r to %r' %
+                             (min_price, max_price))
         self.max_price = max_price
 
     def __repr__(self):
@@ -162,7 +162,7 @@ class PriceRange(object):
             if other.currency != self.min_price.currency:
                 raise ValueError("Cannot subtract price in %r from pricerange"
                                  " in %r" %
-                                 (other.min_price.currency, self.currency))
+                                 (other.currency, self.min_price.currency))
             min_price = self.min_price - other
             max_price = self.max_price - other
             return PriceRange(min_price=min_price, max_price=max_price)
@@ -215,8 +215,6 @@ class Tax(PriceModifier):
     '''
     A generic tax class, provided so all taxers have a common base.
     '''
-    name = None
-
     def apply(self, price_obj):
         return Price(net=price_obj.net,
                      gross=price_obj.gross + self.calculate_tax(price_obj),
@@ -231,7 +229,7 @@ class Tax(PriceModifier):
 
 class LinearTax(Tax):
     '''
-    A linear tax, modifies .
+    Adds a certain fraction on top of the price.
     '''
     def __init__(self, multiplier, name=None):
         self.multiplier = Decimal(multiplier)
@@ -258,6 +256,29 @@ class LinearTax(Tax):
         return price_obj.gross * self.multiplier
 
 
+class FixedDiscount(PriceModifier):
+    '''
+    Adds a fixed amount to the price.
+    '''
+    def __init__(self, amount, name=None):
+        self.amount = amount
+        self.name = name or self.name
+
+    def __repr__(self):
+        return 'FixedDiscount(%r, name=%r)' % (self.amount, self.name)
+
+    def apply(self, price_obj):
+        if price_obj.currency != self.amount.currency:
+            raise ValueError('Cannot apply a discount in %r to a price in %r' %
+                             (self.amount.currency, price_obj.currency))
+        return Price(net=price_obj.net - self.amount.net,
+                     gross=price_obj.gross - self.amount.gross,
+                     currency=price_obj.currency,
+                     previous=price_obj,
+                     modifier=self,
+                     operation=operator.__add__)
+
+
 def inspect_price(price_obj):
     def format_inspect(data):
         if isinstance(data, tuple):
